@@ -8,4 +8,8 @@ if ENV['CODECLIMATE_REPO_TOKEN']
   require "codeclimate-test-reporter"
   CodeClimate::TestReporter.start
 end
+begin
+  require 'byebug'
+rescue LoadError
+end
 require 'test/unit'
